@@ -1,6 +1,5 @@
 from .activation import Activation
-from .condition import Condition
-from .condition import HyperrectangleCondition
+from .condition import Condition, HyperrectangleCondition, DuplicatedFeatures
 from .rule import Rule, RegressionRule, ClassificationRule
 from .ruleset import RuleSet
 from .utils.rule_utils import extract_rules_from_tree
